@@ -162,7 +162,7 @@ def download_and_tag(
             embed_art,
         )
     except Exception as e:
-        logger.error(f"{RED}Error tagging the file: {e}")
+        logger.error(f"{RED}Error tagging the file: {e}", exc_info=True)
 
 
 def download_id_by_type(
@@ -227,7 +227,6 @@ def download_id_by_type(
         else:
             get_extra(meta["image"]["large"], dirn, og_quality=cover_og_quality)
 
-
         if "goodies" in meta:
             try:
                 get_extra(meta["goodies"][0]["url"], dirn, "booklet.pdf")
